@@ -32,11 +32,11 @@ ExtUtils::Install - install files from here to there
 
 =head1 VERSION
 
-2.10
+2.12
 
 =cut
 
-our $VERSION = '2.10';  # <-- do not forget to update the POD section just above this line!
+our $VERSION = '2.12';  # <-- do not forget to update the POD section just above this line!
 $VERSION = eval $VERSION;
 
 =pod
@@ -91,7 +91,7 @@ Dies with a special message.
 
 BEGIN {
     *Is_VMS        = $^O eq 'VMS'     ? sub(){1} : sub(){0};
-    *Is_Win32      = $^O eq 'Win32'   ? sub(){1} : sub(){0};
+    *Is_Win32      = $^O eq 'MSWin32' ? sub(){1} : sub(){0};
     *Is_cygwin     = $^O eq 'cygwin'  ? sub(){1} : sub(){0};
     *CanMoveAtBoot = ($^O eq 'MSWin32' || $^O eq 'cygwin') ? sub(){1} : sub(){0};
 }
